use crate::types::{authentication_data::AuthenticationData, flow::Flow, identifier::Identifier};

#[derive(Debug, serde::Deserialize)]
pub struct RegistrationRequest {
    auth: Option<AuthenticationData>,
    device_id: Option<String>,
    inhibit_login: Option<bool>,
    initial_device_display_name: Option<String>,
    password: Option<String>,
    username: Option<String>,
}

impl RegistrationRequest {
    #[must_use]
    pub fn auth(&self) -> Option<&AuthenticationData> {
        self.auth.as_ref()
    }

    /// Get a reference to the registration request's device id.
    #[must_use]
    pub fn device_id(&self) -> Option<&String> {
        self.device_id.as_ref()
    }

    /// Get the registration request's inhibit login.
    #[must_use]
    pub fn inhibit_login(&self) -> Option<bool> {
        self.inhibit_login
    }

    /// Get a reference to the registration request's initial device display name.
    #[must_use]
    pub fn initial_device_display_name(&self) -> Option<&String> {
        self.initial_device_display_name.as_ref()
    }

    /// Get a reference to the registration request's password.
    #[must_use]
    pub fn password(&self) -> Option<&String> {
        self.password.as_ref()
    }

    /// Get a reference to the registration request's username.
    #[must_use]
    pub fn username(&self) -> Option<&String> {
        self.username.as_ref()
    }
}
